""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.pathx.schemas import apis


class PathXClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(PathXClient, self).__init__(config, transport, middleware, logger)

    def bind_path_xssl(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """BindPathXSSL - 绑定PathX SSL证书

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Port** (list) - (Required) 绑定SSL证书的HTTPS端口。Port.0 Port.1对应多个Port。如果Port不存在则不会绑定
        - **SSLId** (str) - (Required) 证书ID，如果没有指定证书ID也没有申请免费证书，HTTPS接入无法正常工作
        - **UGAId** (str) - (Required) UGA实例ID

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.BindPathXSSLRequestSchema().dumps(d)

        resp = self.invoke("BindPathXSSL", d, **kwargs)
        return apis.BindPathXSSLResponseSchema().loads(resp)

    def create_global_ssh_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateGlobalSSHInstance - 创建GlobalSSH实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Area** (str) - (Required) 填写支持SSH访问IP的地区名称，如“洛杉矶”，“新加坡”，“香港”，“东京”，“华盛顿”，“法兰克福”，“首尔”。Area和AreaCode两者必填一个
        - **AreaCode** (str) - (Required) AreaCode, 区域航空港国际通用代码。Area和AreaCode两者必填一个
        - **Port** (int) - (Required) 源站服务器监听的SSH端口，可取范围[1-65535]，不能使用80，443,  65123端口。如果InstanceType=Free，取值范围缩小为[22,3389],linux系统选择22，windows系统自动选3389。
        - **TargetIP** (str) - (Required) 被SSH访问的源站IP，仅支持IPv4地址。
        - **BandwidthPackage** (int) - Ultimate版本带宽包大小,枚举值：[0,20,40]。单位MB
        - **ChargeType** (str) - 支付方式，如按月：Month、 按年：Year、按时：Dynamic
        - **CouponId** (str) - 使用代金券可冲抵部分费用
        - **ForwardRegion** (str) - InstanceType等于Basic时可以在["cn-bj2","cn-sh2","cn-gd"]中选择1个作为转发机房，其他付费版默认配置三个转发机房
        - **InstanceType** (str) - 枚举值：["Ultimate","Enterprise","Basic","Primary"], 分别代表旗舰版，企业版，基础版，入门版
        - **Quantity** (int) - 购买数量按月购买至月底请传0
        - **Remark** (str) - 备注信息

        **Response**

        - **AcceleratingDomain** (str) - 加速域名，访问该域名可就近接入
        - **InstanceId** (str) - 实例ID，资源唯一标识

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateGlobalSSHInstanceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateGlobalSSHInstance", d, **kwargs)
        return apis.CreateGlobalSSHInstanceResponseSchema().loads(resp)

    def create_path_xssl(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreatePathXSSL - 创建SSL证书，可以把整个 Pem 证书内容传到SSLContent，或者把证书、私钥、CA证书分别传过来

        **Request**

        - **ProjectId** (str) - (Config) 项目ID org-xxx格式。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SSLName** (str) - (Required) SSL证书的名字
        - **CACert** (str) - CA颁发证书内容
        - **PrivateKey** (str) - 加密证书的私钥，不可使用密码保护，开启密码保护后，重启服务需要输入密码
        - **SSLContent** (str) - SSL证书的完整内容，私钥不可使用密码，包括加密证书的私钥、用户证书或CA证书等
        - **SSLType** (str) - 所添加的SSL证书类型，目前只支持Pem格式
        - **UserCert** (str) - 用户自签证书内容

        **Response**

        - **SSLId** (str) - SSL证书的Id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreatePathXSSLRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreatePathXSSL", d, **kwargs)
        return apis.CreatePathXSSLResponseSchema().loads(resp)

    def create_uga_3instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUGA3Instance - 创建全球统一接入加速配置项

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Bandwidth** (int) - (Required) 实例的共享带宽大小，单位Mbps
        - **AccelerationArea** (str) - 加速大区,默认Global,[    "Global":"全球",    "AP":"亚太",    "EU":"欧洲",    "ME":"中东",    "OA":"大洋洲",    "AF":"非洲",    "NA":"北美洲",    "SA":"南美洲"]
        - **AreaCode** (str) - 非必填,如果不填，会根据Domain 和IPList 去选一个最近的源站区域BKK表示AreaCode;曼谷表示Area["BKK":"曼谷","DXB":"迪拜","FRA":"法兰克福","SGN":"胡志明市","HKG":"香港",CGK":"雅加达","LOS":"拉各斯","LHR":"伦敦","LAX":"洛杉矶","MNL":"马尼拉","DME":"莫斯科","BOM":"孟买","MSP":"圣保罗","ICN":"首尔","PVG":"上海","SIN":"新加坡","NRT":"东京","IAD":"华盛顿","TPE": "台北"]
        - **ChargeType** (str) - 支付方式，如按月、按年、按时[Year,Month,Dynamic]
        - **CouponId** (str) - 使用代金券可冲抵部分费用，仅全地域可用的代金券
        - **Name** (str) - 加速配置实例名称,默认PathX
        - **OriginDomain** (str) - 加速源域名，IPList和Domain二选一必填
        - **OriginIPList** (str) - 加速源IP，多个IP用英文半角逗号(,)隔开；IPList和Domain二选一必填
        - **Quantity** (int) - 购买周期
        - **Remark** (str) - 备注项

        **Response**

        - **CName** (str) - 加速域名 用户可把业务域名CName到此域名上
        - **InstanceId** (str) - 加速配置ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUGA3InstanceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUGA3Instance", d, **kwargs)
        return apis.CreateUGA3InstanceResponseSchema().loads(resp)

    def create_uga_3port(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUGA3Port - 创建统一接入加速实例端口，目前仅支持四层TCP端口

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID
        - **TCP** (list) - TCP接入端口，禁用65123端口
        - **TCPRS** (list) - TCP回源端口

        **Response**

        - **Message** (str) - 返回信息 说明

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUGA3PortRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUGA3Port", d, **kwargs)
        return apis.CreateUGA3PortResponseSchema().loads(resp)

    def create_uga_forwarder(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUGAForwarder - 创建加速实例转发器，支持HTTPS接入HTTPS回源、HTTPS接入HTTP回源、HTTP接入HTTP回源、TCP接入TCP回源、UDP接入UDP回源、 支持WSS接入WSS回源、WSS接入WS回源、WS接入WS回源

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGAId** (str) - (Required) 加速配置实例ID
        - **HTTPHTTP** (list) - HTTP接入HTTP回源转发，接入端口。禁用65123端口
        - **HTTPHTTPRS** (list) - HTTP接入HTTP回源转发，源站监听端口
        - **HTTPSHTTP** (list) - HTTPS接入HTTP回源转发，接入端口。禁用65123端口
        - **HTTPSHTTPRS** (list) - HTTPS接入HTTP回源转发，回源端口
        - **HTTPSHTTPS** (list) - HTTPS接入HTTPS回源转发，接入端口。禁用65123端口
        - **HTTPSHTTPSRS** (list) - HTTPS接入HTTPS回源转发，源站监听端口
        - **TCP** (list) - TCP接入端口，禁用65123端口
        - **TCPRS** (list) - TCP回源端口
        - **UDP** (list) - UDP接入端口，禁用65123端口
        - **UDPRS** (list) - UDP回源端口
        - **WSSWS** (list) - WebSocketS接入WebSocket回源转发，接入端口。禁用65123。
        - **WSSWSRS** (list) - WebSocketS接入WebSocket回源转发，源站监听端口。
        - **WSSWSS** (list) - WebSocketS接入WebSocketS回源转发，接入端口。禁用65123。
        - **WSSWSSRS** (list) - WebSocketS接入WebSocketS回源转发，源站监听端口。
        - **WSWS** (list) - WebSocket接入WebSocket回源转发，接入端口。禁用65123。
        - **WSWSRS** (list) - WebSocket接入WebSocket回源转发，源站监听端口

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUGAForwarderRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUGAForwarder", d, **kwargs)
        return apis.CreateUGAForwarderResponseSchema().loads(resp)

    def create_uga_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUGAInstance - 创建全球加速配置项

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Name** (str) - (Required) 加速配置实例名称
        - **Domain** (str) - 加速源域名，IPList和Domain二选一必填
        - **IPList** (str) - 加速源IP，多个IP用英文半角逗号(,)隔开；IPList和Domain二选一必填
        - **TCP** (list) - TCP端口号，已废弃。请使用 CreateUGAForwarder API 创建端口
        - **UDP** (list) - UDP端口号，已废弃。请使用 CreateUGAForwarder API 创建端口

        **Response**

        - **CName** (str) - 加速域名 用户可把业务域名CName到此域名上。注意：未绑定线路情况时 加速域名解析不出IP。
        - **Message** (str) - 返回信息
        - **UGAId** (str) - 加速配置ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUGAInstanceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUGAInstance", d, **kwargs)
        return apis.CreateUGAInstanceResponseSchema().loads(resp)

    def create_upath(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """CreateUPath - 创建UPath

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Bandwidth** (int) - (Required) 当PostPaid为false时，该值为预付费固定带宽；当PostPaid为true时，该值为后付费保底带宽，保底带宽越大可用的上限带宽越大。最小1Mbps,最大带宽由 DescribePathXLineConfig 接口获得。可联系产品团队咨询最大带宽。
        - **LineId** (str) - (Required) 选择的线路，由DescribePathXLineConfig接口提供
        - **Name** (str) - (Required) 名字，便于记忆区分
        - **ChargeType** (str) - 计费模式，默认为Month 按月收费,可选范围['Month','Year','Dynamic']
        - **CouponId** (str) - 代金券Id
        - **PathType** (str) - private:专线线路；public:海外SD-WAN。默认为private。
        - **PostPaid** (bool) - 是否开启后付费, 默认为false ，不开启后付费。当ChargeType为Dynamic时不能开启后付费。
        - **Quantity** (int) - 购买周期，ChargeType为Month时，Quantity默认为0代表购买到月底，按时和按年付费该参数必须大于0

        **Response**

        - **PathId** (str) - 加速线路实例Id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUPathRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUPath", d, **kwargs)
        return apis.CreateUPathResponseSchema().loads(resp)

    def delete_global_ssh_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteGlobalSSHInstance - 删除GlobalSSH实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例Id,资源的唯一标识

        **Response**

        - **Message** (str) - 提示信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteGlobalSSHInstanceRequestSchema().dumps(d)

        resp = self.invoke("DeleteGlobalSSHInstance", d, **kwargs)
        return apis.DeleteGlobalSSHInstanceResponseSchema().loads(resp)

    def delete_path_xssl(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeletePathXSSL - 删除PathX SSL证书

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SSLId** (str) - (Required) SSL证书的ID

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeletePathXSSLRequestSchema().dumps(d)

        resp = self.invoke("DeletePathXSSL", d, **kwargs)
        return apis.DeletePathXSSLResponseSchema().loads(resp)

    def delete_uga_3instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUGA3Instance - 删除全球统一接入转发实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例Id,资源的唯一标识

        **Response**

        - **Message** (str) - 提示信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUGA3InstanceRequestSchema().dumps(d)

        resp = self.invoke("DeleteUGA3Instance", d, **kwargs)
        return apis.DeleteUGA3InstanceResponseSchema().loads(resp)

    def delete_uga_3port(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUGA3Port - 删除统一接入加速实例转发器 按接入端口删除

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID
        - **TCP** (list) - TCP接入端口

        **Response**

        - **Message** (str) - 返回信息 说明

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUGA3PortRequestSchema().dumps(d)

        resp = self.invoke("DeleteUGA3Port", d, **kwargs)
        return apis.DeleteUGA3PortResponseSchema().loads(resp)

    def delete_uga_forwarder(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUGAForwarder - 删除加速实例转发器 按接入端口删除

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGAId** (str) - (Required) 加速配置实例ID
        - **HTTPHTTP** (list) - HTTP接入HTTP回源，接入端口。禁用65123端口
        - **HTTPSHTTP** (list) - HTTPS接入HTTP回源， 接入端口。禁用65123端口
        - **HTTPSHTTPS** (list) - HTTPS接入HTTPS回源， 接入端口。禁用65123端口
        - **TCP** (list) - TCP接入端口
        - **UDP** (list) - UDP接入端口
        - **WSSWS** (list) - WebSocketS接入WebSocket回源， 接入端口。禁用65123端口。
        - **WSSWSS** (list) - WebSocketS接入WebSocketS回源， 接入端口。禁用65123端口
        - **WSWS** (list) - WebSocket接入WebSocket回源， 接入端口。禁用65123端口

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUGAForwarderRequestSchema().dumps(d)

        resp = self.invoke("DeleteUGAForwarder", d, **kwargs)
        return apis.DeleteUGAForwarderResponseSchema().loads(resp)

    def delete_uga_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUGAInstance - 删除全球加速服务加速配置

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UGAId** (str) - (Required) 加速配置实例ID

        **Response**

        - **Message** (str) - 消息提示

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUGAInstanceRequestSchema().dumps(d)

        resp = self.invoke("DeleteUGAInstance", d, **kwargs)
        return apis.DeleteUGAInstanceResponseSchema().loads(resp)

    def delete_upath(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """DeleteUPath - 删除UPath

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UPathId** (str) - (Required) 加速线路实例ID

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUPathRequestSchema().dumps(d)

        resp = self.invoke("DeleteUPath", d, **kwargs)
        return apis.DeleteUPathResponseSchema().loads(resp)

    def describe_global_ssh_area(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeGlobalSSHArea -

        **Request**

        - **ProjectId** (str) - (Config)
        - **Region** (str) - (Config)

        **Response**

        - **AreaSet** (list) - 见 **GlobalSSHArea** 模型定义
        - **Message** (str) -

        **Response Model**

        **GlobalSSHArea**
        - **Area** (str) -
        - **AreaCode** (str) -
        - **RegionSet** (list) -


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeGlobalSSHAreaRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("DescribeGlobalSSHArea", d, **kwargs)
        return apis.DescribeGlobalSSHAreaResponseSchema().loads(resp)

    def describe_global_ssh_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeGlobalSSHInstance - 获取GlobalSSH实例列表（传实例ID获取单个实例信息，不传获取项目下全部实例）

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - 实例ID，资源唯一标识

        **Response**

        - **InstanceSet** (list) - 见 **GlobalSSHInfo** 模型定义

        **Response Model**

        **GlobalSSHInfo**
        - **AcceleratingDomain** (str) - GlobalSSH分配的加速域名。
        - **Area** (str) - 被SSH访问的IP所在地区
        - **BandwidthPackage** (int) - globalssh Ultimate带宽包大小
        - **ChargeType** (str) - 支付周期，如Month,Year,Dynamic等
        - **CreateTime** (int) - 资源创建时间戳
        - **Expire** (bool) - 是否过期
        - **ExpireTime** (int) - 资源过期时间戳
        - **ForwardRegion** (str) - InstanceType为Basic版本时，需要展示具体分配的转发机房
        - **GlobalSSHPort** (int) - InstanceType等于Free时，由系统自动分配，不等于源站Port值。InstanceType不等于Free时，与源站Port值相同。
        - **InstanceId** (str) - 实例ID，资源唯一标识
        - **InstanceType** (str) - 枚举值：["Enterprise","Basic","Free","Welfare"], 分别代表企业版，基础版本，免费版本，较早的公测免费版
        - **Port** (int) - 源站服务器监听的SSH端口，windows系统为RDP端口
        - **Remark** (str) - 备注信息
        - **TargetIP** (str) - 被SSH访问的源站 IPv4地址。


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeGlobalSSHInstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeGlobalSSHInstance", d, **kwargs)
        return apis.DescribeGlobalSSHInstanceResponseSchema().loads(resp)

    def describe_path_x_line_config(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePathXLineConfig - 获取全球加速线路信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_

        **Response**

        - **LineSet** (list) - 见 **UGAALine** 模型定义

        **Response Model**

        **UGAALine**
        - **LineDetail** (list) - 见 **LineDetail** 模型定义
        - **LineFrom** (str) - 线路源
        - **LineFromName** (str) - 线路源中文名称
        - **LineId** (str) - 线路计费Id
        - **LineTo** (str) - 线路目的
        - **LineToName** (str) - 线路目的中文名称
        - **MaxBandwidth** (int) - 线路可售最大带宽


        **LineDetail**
        - **LineFrom** (str) - 线路源
        - **LineFromName** (str) - 线路源中文名称
        - **LineId** (str) - 线路计费Id
        - **LineTo** (str) - 线路目的
        - **LineToName** (str) - 线路目的中文名称


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribePathXLineConfigRequestSchema().dumps(d)

        resp = self.invoke("DescribePathXLineConfig", d, **kwargs)
        return apis.DescribePathXLineConfigResponseSchema().loads(resp)

    def describe_path_xssl(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePathXSSL - 获取SSL证书信息,支持分页，支持按证书名称 证书域名模糊搜索

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Limit** (int) - 最大返回条数，默认100，最大400
        - **Offset** (int) - 偏移值 默认为0
        - **SSLId** (str) - SSL证书的Id，不传分页获取证书列表
        - **SearchValue** (str) - 不为空则按证书名称、证书域名模糊搜索 分页返回结果

        **Response**

        - **DataSet** (list) - 见 **PathXSSLSet** 模型定义
        - **TotalCount** (int) - 符合条件的证书总数

        **Response Model**

        **PathXSSLSet**
        - **CreateTime** (int) - SSL证书的创建时间 时间戳
        - **ExpireTime** (int) - 证书过期时间 时间戳
        - **SSLBindedTargetSet** (list) - 见 **SSLBindedTargetSet** 模型定义
        - **SSLContent** (str) - SSL证书内容
        - **SSLId** (str) - SSL证书的Id
        - **SSLMD5** (str) - SSL证书（用户证书、私钥、ca证书合并）内容md5值
        - **SSLName** (str) - SSL证书的名字
        - **SourceType** (int) - 证书来源，0：用户上传 1: 免费颁发
        - **SubjectName** (str) - 证书域名


        **SSLBindedTargetSet**
        - **ResourceId** (str) - SSL证书绑定到的实例ID
        - **ResourceName** (str) - SSL证书绑定到的实例名称


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribePathXSSLRequestSchema().dumps(d)

        resp = self.invoke("DescribePathXSSL", d, **kwargs)
        return apis.DescribePathXSSLResponseSchema().loads(resp)

    def describe_uga_3area(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGA3Area - 获取全球接入源站可选列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Domain** (str) - 域名，非必填。如果填IP或者域名，会推荐一个地域在返回列表的第一个
        - **IPList** (str) - IP集合，非必填。如果填IP或者域名，会推荐一个地域在返回列表的第一个，源站IP集合，以逗号分隔[127.0.0.1,127.0.0.2]

        **Response**

        - **AreaSet** (list) - 见 **ForwardArea** 模型定义
        - **Message** (str) - 提示信息

        **Response Model**

        **ForwardArea**
        - **Area** (str) - 源站区域中文
        - **AreaCode** (str) - 源站区域代码
        - **ContinentCode** (str) - 大陆代码
        - **CountryCode** (str) - 国家代码
        - **FlagEmoji** (str) - 国旗 emoji
        - **FlagUnicode** (str) - 国旗unicode


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGA3AreaRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGA3Area", d, **kwargs)
        return apis.DescribeUGA3AreaResponseSchema().loads(resp)

    def describe_uga_3instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGA3Instance - 获取全球统一接入加速服务加速配置信息，指定实例ID返回单个实例。未指定实例ID时 指定分页参数 则按创建时间降序 返回记录

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - 加速配置实例ID，如果传了实例ID 则返回匹配实例ID的记录；如果没传则返回 ProjectId 下全部实例且符合分页要求
        - **Limit** (int) - 返回的最大条数，默认为100，最大值400
        - **Offset** (int) - 偏移量，默认为0

        **Response**

        - **ForwardInstanceInfos** (list) - 见 **ForwardInfo** 模型定义
        - **TotalCount** (int) - 符合条件的总数

        **Response Model**

        **SrcAreaInfo**
        - **Area** (str) - AreaCode对应城市名
        - **AreaCode** (str) - AreaCode ,城市机场代码
        - **FlagEmoji** (str) - 国旗Emoji
        - **FlagUnicode** (str) - 国旗Unicode


        **ForwardTask**
        - **Port** (int) - 加速端口
        - **Protocol** (str) - 转发协议，枚举值["TCP"，"UDP"，"HTTPHTTP"，"HTTPSHTTP"，"HTTPSHTTPS"，"WSWS"，"WSSWS"，"WSSWSS"]。TCP和UDP代表四层转发，其余为七层转发。
        - **RSPort** (int) - 源站服务器监听的端口号


        **OutPublicIpInfo**
        - **Area** (str) - 线路回源节点机房代号
        - **IP** (str) - 线路回源节点EIP


        **AccelerationAreaInfos**
        - **AccelerationArea** (str) - 加速区code
        - **AccelerationNodes** (list) - 见 **SrcAreaInfo** 模型定义


        **ForwardInfo**
        - **AccelerationArea** (str) - 加速大区代码
        - **AccelerationAreaInfos** (list) - 见 **AccelerationAreaInfos** 模型定义
        - **AccelerationAreaName** (str) - 加速大区名称
        - **Bandwidth** (int) - 购买的带宽值
        - **CName** (str) - 加速域名
        - **ChargeType** (str) - 计费方式
        - **CreateTime** (int) - 资源创建时间
        - **Domain** (str) - 源站域名
        - **EgressIpList** (list) - 见 **OutPublicIpInfo** 模型定义
        - **ExpireTime** (int) - 资源过期时间
        - **IPList** (list) - 源站IP列表，多个值由半角英文逗号相隔
        - **InstanceId** (str) - 加速配置ID
        - **Name** (str) - 加速实例名称
        - **OriginArea** (str) - 源站中文名
        - **OriginAreaCode** (str) - 源站AreaCode
        - **PortSets** (list) - 见 **ForwardTask** 模型定义
        - **Remark** (str) - 备注


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGA3InstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGA3Instance", d, **kwargs)
        return apis.DescribeUGA3InstanceResponseSchema().loads(resp)

    def describe_uga_3optimization(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGA3Optimization - 获取全球接入UGA3线路加速化情况

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **AreaCode** (str) - (Required) 源站AreaCode
        - **AccelerationArea** (str) - 加速大区,默认Global,[    "Global":"全球",    "AP":"亚太",    "EU":"欧洲",    "ME":"中东",    "OA":"大洋洲",    "AF":"非洲",    "NA":"北美洲",    "SA":"南美洲"]
        - **TimeRange** (str) - 默认一天 ，枚举类型["Hour","Day","Week"]

        **Response**

        - **AccelerationInfos** (list) - 见 **AccelerationInfo** 模型定义

        **Response Model**

        **NodeDelays**
        - **Area** (str) - 加速区域
        - **AreaCode** (str) - 加速区域Code
        - **CountryCode** (str) - 国家代码
        - **FlagEmoji** (str) - 国旗Emoji
        - **FlagUnicode** (str) - 国旗Code
        - **Latency** (float) - 加速延迟
        - **LatencyInternet** (float) - 公网延迟
        - **LatencyOptimization** (float) - 加速提升比例
        - **Loss** (float) - 加速后丢包率
        - **LossInternet** (float) - 原始丢包率
        - **LossOptimization** (float) - 丢包下降比例


        **AccelerationInfo**
        - **AccelerationArea** (str) - 加速大区代码
        - **AccelerationName** (str) - 加速大区名称
        - **NodeInfo** (list) - 见 **NodeDelays** 模型定义


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGA3OptimizationRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGA3Optimization", d, **kwargs)
        return apis.DescribeUGA3OptimizationResponseSchema().loads(resp)

    def describe_uga_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGAInstance - 获取全球加速服务加速配置信息，指定实例ID返回单个实例。未指定实例ID时 指定分页参数 则按创建时间降序 返回记录

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Limit** (int) - 返回的最大条数，默认为100，最大值400
        - **Offset** (int) - 偏移量，默认为0
        - **UGAId** (str) - 加速配置实例ID，如果传了实例ID 则返回匹配实例ID的记录；如果没传则返回 ProjectId 下全部实例且符合分页要求

        **Response**

        - **TotalCount** (int) - 符合条件的总数
        - **UGAList** (list) - 见 **UGAAInfo** 模型定义

        **Response Model**

        **UGAAInfo**
        - **CName** (str) - 加速域名，请在加速区域配置您的业务域名的CName记录值为加速域名
        - **Domain** (str) - 源站域名
        - **IPList** (list) - 源站IP列表，多个值由半角英文逗号相隔
        - **L4ForwarderSet** (list) - 见 **UGAL4Forwarder** 模型定义
        - **L7ForwarderSet** (list) - 见 **UGAL7Forwarder** 模型定义
        - **Location** (str) - 源站所在区域，加速实例在绑定线路后会自动设置该值。console页面上通过该值过滤加速实例可以绑定的upath实例。注意：缺少该值会导致在console上无法修改线路
        - **OutPublicIpList** (list) - 见 **OutPublicIpInfo** 模型定义
        - **TaskSet** (list) - 见 **UGAATask** 模型定义
        - **UGAId** (str) - 加速配置实例ID
        - **UGAName** (str) - 加速配置名称
        - **UPathSet** (list) - 见 **UPathSet** 模型定义


        **UGAL4Forwarder**
        - **Port** (int) - 接入端口
        - **Protocol** (str) - 转发协议，枚举值["TCP"，"UDP"，"HTTPHTTP"，"HTTPSHTTP"，"HTTPSHTTPS"]。TCP和UDP代表四层转发，其余为七层转发
        - **RSPort** (int) - RSPort，源站监听端口


        **UGAL7Forwarder**
        - **Port** (int) - 接入端口
        - **Protocol** (str) - 转发协议，枚举值["TCP"，"UDP"，"HTTPHTTP"，"HTTPSHTTP"，"HTTPSHTTPS"]。TCP和UDP代表四层转发，其余为七层转发
        - **RSPort** (int) - RSPort，源站监听端口
        - **SSLId** (str) - 证书ID
        - **SSLName** (str) - 证书名称


        **OutPublicIpInfo**
        - **Area** (str) - 线路回源节点机房代号
        - **IP** (str) - 线路回源节点EIP


        **UGAATask**
        - **Port** (int) - 接入端口
        - **Protocol** (str) - 转发协议，枚举值["TCP"，"UDP"，"HTTPHTTP"，"HTTPSHTTP"，"HTTPSHTTPS"]。TCP和UDP代表四层转发，其余为七层转发


        **UPathSet**
        - **Bandwidth** (int) - 带宽 Mbps, 1~800Mbps
        - **LineFrom** (str) - 线路起点英文代号，加速区域
        - **LineFromName** (str) - 线路起点中文名字，加速区域
        - **LineId** (str) - 线路ID
        - **LineTo** (str) - 线路对端英文代号，源站区域
        - **LineToName** (str) - 线路对端中文名字，源站区域
        - **UPathId** (str) - UPath 实例ID
        - **UPathName** (str) - UPath名字


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGAInstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGAInstance", d, **kwargs)
        return apis.DescribeUGAInstanceResponseSchema().loads(resp)

    def describe_upath(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUPath - 获取加速线路信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UPathId** (str) - 如果不填参数 返回 ProjectId 下所有的线路资源，填此参数则返回upath实例ID匹配的线路

        **Response**

        - **UPathSet** (list) - 见 **UPathInfo** 模型定义

        **Response Model**

        **UPathInfo**
        - **Bandwidth** (int) - 带宽，单位Mbps
        - **ChargeType** (str) - 计费模式，默认为Month 按月收费,可选范围['Month','Year','Dynamic']
        - **CreateTime** (int) - UPath创建的时间，10位时间戳
        - **ExpireTime** (int) - UPath的过期时间，10位时间戳
        - **LineFromName** (str) - 线路入口名称
        - **LineId** (str) - 选择的线路
        - **LineToName** (str) - 线路出口名称
        - **Name** (str) - UPath实例名字
        - **OutPublicIpList** (list) - 见 **OutPublicIpInfo** 模型定义
        - **PostPaid** (bool) - 是否为后付费实例
        - **UGAList** (list) - 见 **PathXUGAInfo** 模型定义
        - **UPathId** (str) - UPath加速线路实例ID


        **OutPublicIpInfo**
        - **Area** (str) - 线路回源节点机房代号
        - **IP** (str) - 线路回源节点EIP


        **PathXUGAInfo**
        - **Domain** (str) - 源站域名
        - **IPList** (list) - 源站IP列表，多个值由半角英文逗号相隔
        - **UGAId** (str) - 加速配置ID


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUPathRequestSchema().dumps(d)

        resp = self.invoke("DescribeUPath", d, **kwargs)
        return apis.DescribeUPathResponseSchema().loads(resp)

    def describe_upath_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUPathTemplate - 查询UPath的监控模板

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UPathId** (str) - (Required) 加速线路实例ID,格式 upath-xxxx

        **Response**

        - **DataSet** (list) - 见 **AlarmRuler** 模型定义

        **Response Model**

        **AlarmRuler**
        - **AlarmFrequency** (int) - 告警探测周期，单位秒
        - **AlarmStrategy** (str) - 收敛策略，可选范围 ['Exponential','Continuous','Once']，分别对应指数递增、连续告警、单次告警
        - **AlarmTemplateRuleId** (int) - 告警模板策略ID
        - **Compare** (str) - 比较策略，可选 ['GE','LE']  分别代表不小于和不大于
        - **ContactGroupId** (int) - 联系组ID
        - **MetricName** (str) - 告警指标名称, 所有n的个数必须一致。目前仅允许以下四项：UpathNetworkOut:出向带宽，UpathNetworkIn:入向带宽，UpathNetworkOutUsage:出向带宽使用率，UpathNetworkInUsage:入向带宽使用率
        - **ResourceType** (str) - 资源类型
        - **Threshold** (int) - 告警阈值，带宽使用率的阈值范围是[50,100]的正整数，带宽告警阈值为1000000的倍数, 如大于2Mbps则告警 阈值应该传 2000000
        - **TriggerCount** (int) - 告警触发周期（次数）


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUPathTemplateRequestSchema().dumps(d)

        resp = self.invoke("DescribeUPathTemplate", d, **kwargs)
        return apis.DescribeUPathTemplateResponseSchema().loads(resp)

    def get_global_ssh_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetGlobalSSHPrice - 获取GlobalSSH价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **ChargeType** (str) - 计费类型：Dynamic，Month，Year
        - **InstanceType** (str) - 版本类型。枚举值，Enterprise:企业版；Basic:基础版。可不填，默认为Basic。
        - **Quantity** (int) - 购买周期，如果ChargeType为Month，Quantity默认为0；其他情况必须为大于0的整数

        **Response**

        - **Price** (float) - 价格,返回单位为元

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetGlobalSSHPriceRequestSchema().dumps(d)

        resp = self.invoke("GetGlobalSSHPrice", d, **kwargs)
        return apis.GetGlobalSSHPriceResponseSchema().loads(resp)

    def get_global_ssh_update_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetGlobalSSHUpdatePrice - 获取GlobalSSH升级价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **InstanceType** (str) - (Required) 升级后的实例类型。枚举值，Enterprise:企业版；Basic:基础版。
        - **ChargeType** (str) - 计费类型：Dynamic，Month，Year。从免费版升级到付费版必须传，其他情况不需要传
        - **InstanceId** (str) - 实例ID，唯一资源标识。从免费版升级到付费版可不填，其他情况必填。
        - **Quantity** (int) - 购买周期，如果ChargeType为Month，Quantity可以不填默认为0；其他情况必须为正整数。

        **Response**

        - **Price** (float) - 价格,返回单位为元。正数表示付费升级，负数表示降级退费。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetGlobalSSHUpdatePriceRequestSchema().dumps(d)

        resp = self.invoke("GetGlobalSSHUpdatePrice", d, **kwargs)
        return apis.GetGlobalSSHUpdatePriceResponseSchema().loads(resp)

    def get_path_x_metric(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetPathXMetric - 获取全球加速监控信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **BeginTime** (int) - (Required) 查询起始时间，10位长度时间戳
        - **EndTime** (int) - (Required) 查询结束时间，10位长度时间戳
        - **LineId** (str) - (Required) 具体线路id，调用DescribePathXLineConfig接口获取线路列表
        - **MetricName** (list) - (Required) 查询监控的指标项。目前仅允许以下四项：NetworkOut:出向带宽，NetworkIn:入向带宽，NetworkOutUsage:出向带宽使用率，NetworkInUsage:入向带宽使用率
        - **ResourceId** (str) - (Required) ResourceId，如upath ID  和 uga ID
        - **ResourceType** (str) - (Required) upath:加速线路,uga:加速实例

        **Response**

        - **DataSet** (dict) - 见 **MetricPeriod** 模型定义

        **Response Model**

        **MetricPeriod**
        - **NetworkIn** (list) - 见 **MatricPoint** 模型定义
        - **NetworkInUsage** (list) - 见 **MatricPoint** 模型定义
        - **NetworkOut** (list) - 见 **MatricPoint** 模型定义
        - **NetworkOutUsage** (list) - 见 **MatricPoint** 模型定义


        **MatricPoint**
        - **Timestamp** (int) - 时间戳
        - **Value** (int) - 监控点数值


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetPathXMetricRequestSchema().dumps(d)

        resp = self.invoke("GetPathXMetric", d, **kwargs)
        return apis.GetPathXMetricResponseSchema().loads(resp)

    def get_uga_3metric(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUGA3Metric - 获取全地域加速监控信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **BeginTime** (int) - (Required) 查询起始时间，10位长度时间戳
        - **EndTime** (int) - (Required) 查询结束时间，10位长度时间戳
        - **InstanceId** (str) - (Required) 资源ID
        - **AreaCode** (str) - 子线路AreaCode ,子线路的时候传，不是子线路可以不传
        - **IsSubline** (bool) - 是否为子线路。为了简化查询,true 会返回所有子线路监控项可以，false:返回所有汇总的监控数据
        - **MetricName** (list) - 查询监控的指标项。可不传	NetworkOut:出口总带宽	NetworkIn：入口总带宽	NetworkOutUsage：出口带宽使用率	NetworkInUsage：入口总带宽使用率	NetworkOutSubline ：子线路出口带宽	NetworkInSubline：子线路入口带宽	Delay：线路平均延迟	DelaySubline：子线路延迟	ConnectCount：当前连接数	ConnectCountSubline：子线路当前连接数	DelayPromote：延迟提升	DelayPromoteSubline：子线路延迟提升

        **Response**

        - **DataSet** (dict) - 见 **UGA3Metric** 模型定义

        **Response Model**

        **MatricPoint**
        - **Timestamp** (int) - 时间戳
        - **Value** (int) - 监控点数值


        **UGA3Metric**
        - **ConnectCount** (list) - 见 **MatricPoint** 模型定义
        - **ConnectCountSubline** (list) - 见 **MatricPoint** 模型定义
        - **Delay** (list) - 见 **MatricPoint** 模型定义
        - **DelayPromote** (list) - 见 **MatricPoint** 模型定义
        - **DelayPromoteSubline** (list) - 见 **MatricPoint** 模型定义
        - **DelaySubline** (list) - 见 **MatricPoint** 模型定义
        - **NetworkIn** (list) - 见 **MatricPoint** 模型定义
        - **NetworkInSubline** (list) - 见 **MatricPoint** 模型定义
        - **NetworkInUsage** (list) - 见 **MatricPoint** 模型定义
        - **NetworkOut** (list) - 见 **MatricPoint** 模型定义
        - **NetworkOutSubline** (list) - 见 **MatricPoint** 模型定义
        - **NetworkOutUsage** (list) - 见 **MatricPoint** 模型定义


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUGA3MetricRequestSchema().dumps(d)

        resp = self.invoke("GetUGA3Metric", d, **kwargs)
        return apis.GetUGA3MetricResponseSchema().loads(resp)

    def get_uga_3price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUGA3Price - 获取全球统一接入转发实例价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **AreaCode** (str) - (Required) 源站区域
        - **Bandwidth** (int) - (Required) 共享带宽大小
        - **AccelerationArea** (str) - 加速大区,默认返回所有加速大区价格
        - **ChargeType** (str) - 计费方式，默认按月支付。Month: 按月; Year: 按年; Dynamic: 按小时收
        - **Quantity** (int) - 购买时间数量，当ChargeType为Month时 Quantity默认为0，代表购买至月底。按年按小时必须为大于0

        **Response**

        - **UGA3Price** (list) - 见 **UGA3Price** 模型定义

        **Response Model**

        **UGA3Price**
        - **AccelerationArea** (str) - 加速大区代码
        - **AccelerationAreaName** (str) - 加速大区名称
        - **AccelerationBandwidthPrice** (float) - 加速配置带宽价格
        - **AccelerationForwarderPrice** (float) - 转发配置价格


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUGA3PriceRequestSchema().dumps(d)

        resp = self.invoke("GetUGA3Price", d, **kwargs)
        return apis.GetUGA3PriceResponseSchema().loads(resp)

    def get_uga_3update_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUGA3UpdatePrice - 全球统一接入获取实例更新价格（增加、删退）

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 资源ID
        - **AccelerationArea** (str) - 暂未支持，加速大区，在更换加速大区的时候使用
        - **AreaCode** (str) - 暂未支持，源站区域
        - **Bandwidth** (int) - 只有升级带宽的时候有价格变化

        **Response**

        - **Price** (float) - 价格 元。大于0需付费，小于0则退费。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUGA3UpdatePriceRequestSchema().dumps(d)

        resp = self.invoke("GetUGA3UpdatePrice", d, **kwargs)
        return apis.GetUGA3UpdatePriceResponseSchema().loads(resp)

    def modify_global_ssh_port(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyGlobalSSHPort - 修改GlobalSSH端口

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例ID,资源唯一标识。当前仅收费版GlobalSSH实例可以修改端口。
        - **Port** (int) - (Required) 源站服务器监听的SSH端口号。收费版本端口范围[1,65535]且不能为80，443，65123端口。免费版不支持修改端口。

        **Response**

        - **Message** (str) - 提示信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyGlobalSSHPortRequestSchema().dumps(d)

        resp = self.invoke("ModifyGlobalSSHPort", d, **kwargs)
        return apis.ModifyGlobalSSHPortResponseSchema().loads(resp)

    def modify_global_ssh_remark(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyGlobalSSHRemark - 修改GlobalSSH备注

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例ID,资源唯一标识
        - **Remark** (str) - 备注信息，不填默认为空字符串

        **Response**

        - **Message** (str) - 接口返回消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyGlobalSSHRemarkRequestSchema().dumps(d)

        resp = self.invoke("ModifyGlobalSSHRemark", d, **kwargs)
        return apis.ModifyGlobalSSHRemarkResponseSchema().loads(resp)

    def modify_global_ssh_type(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyGlobalSSHType - 修改GlobalSSH实例类型，仅支持低版本升级到高版本，不支持高版本降级到低版本

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **InstanceId** (str) - (Required) 实例ID,资源唯一标识
        - **InstanceType** (str) - (Required) 取值范围["Enterprise","Basic"]，分别对应企业版和基础版，表示升级后的实例类型。比如从Free版本升级为Basic版或Enterprise版，不可从收费版降级为免费版，或从企业版降级为基础版
        - **ChargeType** (str) - 支付方式，如按月、按年、按时
        - **CouponId** (str) - 可抵扣费用的券，通常不使用
        - **Quantity** (str) - 购买时间，当ChargeType为Month，Quantity为0代表购买到月底

        **Response**

        - **Message** (str) - 提示信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyGlobalSSHTypeRequestSchema().dumps(d)

        resp = self.invoke("ModifyGlobalSSHType", d, **kwargs)
        return apis.ModifyGlobalSSHTypeResponseSchema().loads(resp)

    def modify_uga_3bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUGA3Bandwidth - 修改统一接入加速配置带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID，格式uga3-xxxx
        - **Bandwidth** (int) - 带宽大小，范围[1,100]，不传则不更新
        - **CouponId** (str) - 需要全地域可用的代金券

        **Response**

        - **Message** (str) - 补充描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUGA3BandwidthRequestSchema().dumps(d)

        resp = self.invoke("ModifyUGA3Bandwidth", d, **kwargs)
        return apis.ModifyUGA3BandwidthResponseSchema().loads(resp)

    def modify_uga_3instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUGA3Instance - 修改统一接入加速配置属性，如Name，ReMark

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID，格式uga-xxxx。不支持GlobalSSH实例。
        - **Name** (str) - 加速配置实例名称，不填或空字符串则不更新
        - **Remark** (str) - 备注信息，暂时前端为使用

        **Response**

        - **Message** (str) - 补充描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUGA3InstanceRequestSchema().dumps(d)

        resp = self.invoke("ModifyUGA3Instance", d, **kwargs)
        return apis.ModifyUGA3InstanceResponseSchema().loads(resp)

    def modify_uga_3origin_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUGA3OriginInfo - Domain， IPList注意：修改Domain或IPList时， 请确保源站服务端口已经开启且外网防火墙允许pathx出口ip访问。

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID，格式uga3-xxxx。
        - **OriginDomain** (str) - (Required) 加速源域名，仅支持1个域名。修改源站时 OriginIPList和OriginDomain至少填一个。OriginIPList和OriginDomain都填时 以Domain为准,如果两个都不填，不修改
        - **OriginIPList** (str) - (Required) ，加速源IP，多个IP用英文半角逗号(,)隔开。修改源站时 ，OriginIPList和OriginDomain至少填一个。OriginIPList和OriginDomain都填时 以OriginDomain为准。如果两个都不填，不修改

        **Response**

        - **Action** (str) - 操作名称
        - **Message** (str) - 补充描述信息
        - **RetCode** (int) - 返回码

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUGA3OriginInfoRequestSchema().dumps(d)

        resp = self.invoke("ModifyUGA3OriginInfo", d, **kwargs)
        return apis.ModifyUGA3OriginInfoResponseSchema().loads(resp)

    def modify_uga_3port(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUGA3Port - 修改统一接入加速实例端口,目前仅支持四层TCP端口

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 加速配置实例ID
        - **TCP** (list) - TCP接入端口，禁用65123端口
        - **TCPRS** (list) - TCP回源端口

        **Response**

        - **Message** (str) - 返回信息 说明

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUGA3PortRequestSchema().dumps(d)

        resp = self.invoke("ModifyUGA3Port", d, **kwargs)
        return apis.ModifyUGA3PortResponseSchema().loads(resp)

    def modify_upath_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUPathBandwidth - 修改加速线路带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Bandwidth** (int) - (Required) 线路带宽，单位Mbps。最小1Mbps,最大带宽由 DescribePathXLineConfig 接口获得。如需更大带宽，请联系产品团队。
        - **UPathId** (str) - (Required) UPath 加速线路实例Id

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUPathBandwidthRequestSchema().dumps(d)

        resp = self.invoke("ModifyUPathBandwidth", d, **kwargs)
        return apis.ModifyUPathBandwidthResponseSchema().loads(resp)

    def modify_upath_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUPathTemplate - 修改UPath监控告警项

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UPathId** (str) - (Required) 加速线路实例ID
        - **AlarmFrequency** (list) - 告警探测周期，单位：秒
        - **AlarmStrategy** (list) - 收敛策略，可选范围 ['Exponential','Continuous','Once']，分别对应指数递增、连续告警、单次告警
        - **Compare** (list) - 比较策略，可选 ['GE','LE']  分别代表不小于和不大于
        - **ContactGroupId** (list) - 告警组id
        - **MetricName** (list) - 告警指标名称, 所有n的个数必须一致。目前仅允许以下四项：UpathNetworkOut:出向带宽，UpathNetworkIn:入向带宽，UpathNetworkOutUsage:出向带宽使用率，UpathNetworkInUsage:入向带宽使用率
        - **Threshold** (list) - 告警阈值，带宽使用率的阈值范围是[50,100]的正整数，带宽告警阈值为1000000的倍数, 如大于2Mbps则告警 阈值应该传 2000000
        - **TriggerCount** (list) - 告警触发周期（次数）

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUPathTemplateRequestSchema().dumps(d)

        resp = self.invoke("ModifyUPathTemplate", d, **kwargs)
        return apis.ModifyUPathTemplateResponseSchema().loads(resp)

    def uga_bind_upath(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UGABindUPath - UGA绑定UPath

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UGAId** (str) - (Required) 加速配置实例ID，格式uga-xxxx
        - **UPathId** (str) - (Required) 加速线路实例ID，格式upath-xxx
        - **CouponId** (str) - 代金券

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UGABindUPathRequestSchema().dumps(d)

        resp = self.invoke("UGABindUPath", d, **kwargs)
        return apis.UGABindUPathResponseSchema().loads(resp)

    def uga_un_bind_upath(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UGAUnBindUPath - UGA与UPath解绑

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **UGAId** (str) - (Required) 加速配置实例ID 格式uga-xxx
        - **UPathId** (str) - (Required) 加速线路实例ID 格式upath-xxx

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UGAUnBindUPathRequestSchema().dumps(d)

        resp = self.invoke("UGAUnBindUPath", d, **kwargs)
        return apis.UGAUnBindUPathResponseSchema().loads(resp)

    def un_bind_path_xssl(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UnBindPathXSSL - 解绑PathX SSL 证书

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Port** (list) - (Required) 解绑SSL证书的HTTPS端口。Port.0 Port.1格式 端口错误则解绑失败。
        - **SSLId** (str) - (Required) SSL证书ID。
        - **UGAId** (str) - (Required) UGA实例ID。

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UnBindPathXSSLRequestSchema().dumps(d)

        resp = self.invoke("UnBindPathXSSL", d, **kwargs)
        return apis.UnBindPathXSSLResponseSchema().loads(resp)

    def update_path_x_whitelist(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdatePathXWhitelist - 更新入口白名单,仅限GlobalSSH 实例使用。其他uga-实例不生效

        **Request**

        - **ProjectId** (str) - (Config) 项目ID,如org-xxxx。请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) GlobalSSH实例ID，资源唯一标识
        - **Whitelist** (list) - 白名单规则,例如 "Whitelist.0": "192.168.1.1/24|tcp|22"，"Whitelist.1": "192.168.1.2|tcp|8080:8090"，第一个参数为ip或ip段，第二个参数代表协议（tcp/udp），第三个参数代表端口号或端口范围（使用 ':' 隔开）；可以添加多条规则（递增Whitelist.n字段内的n值）；此接口需要列出全部规则，例如不填则为清空白名单规则，如若需要增量添加，使用InsertPathXWhitelist接口,globalssh 没有端口范围：端口设置成加速端口，协议设置成tcp:ip|tcp|加速端口

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UpdatePathXWhitelistRequestSchema().dumps(d)

        resp = self.invoke("UpdatePathXWhitelist", d, **kwargs)
        return apis.UpdatePathXWhitelistResponseSchema().loads(resp)



import logging

from ucloud.core.typesystem import schema, fields


class ConfigSchema(schema.Schema):
    fields = {
        "region": fields.Str(),
        "project_id": fields.Str(),
        "base_url": fields.Str(default="https://api.ucloud.cn"),
        "user_agent": fields.Str(),
        "timeout": fields.Int(default=30),
        "max_retries": fields.Int(default=0),
        "log_level": fields.Int(default=logging.INFO),
        "validate_request": fields.Bool(default=True),
        "ssl_verify": fields.Bool(default=True),
        "ssl_cacert": fields.Str(),
        "ssl_cert": fields.Str(),
        "ssl_key": fields.Str(),
    }


class Config:
    """
    Config is the config of ucloud sdk, use for setting up

    :type region: str
    :param region: Region is the region of backend service,
        See also `Region list Documentation <https://docs.ucloud.cn/api/summary/regionlist>`_
    :type project_id: str
    :param project_id: ProjectId is the unique identify of project, used for organize resources,
                       Most of resources should belong to a project. Sub-Account must have an project id.
                       See also `Project list Documentation <https://docs.ucloud.cn/api/summary/get_project_list>`_
    :type base_url: str
    :param base_url: BaseUrl is the url of backend api
    :param user_agent: UserAgent is an attribute for sdk client, used for distinguish who is using sdk.
                       See also `User Agent <https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/User-Agent>`_
                       It will be appended to the end of sdk user-agent.
                       eg. "MyAPP/0.10.1" -> "Python/3.7.0 Python-SDK/0.1.0 MyAPP/0.10.1"
    :type timeout: int
    :param timeout: Timeout is timeout for every request.
    :type max_retries: int
    :param max_retries: MaxRetries is the number of max retry times.
                        Set MaxRetries more than 0 to enable auto-retry for network and service availability problem
                        if auto-retry is enabled, it will enable default retry policy using exponential backoff.
    :type log_level: int
    :param log_level:  LogLevel is equal to builtin logging level,
        if logLevel not be set, use INFO level as default.
    """

    def __init__(
        self,
        region: str = None,
        project_id: str = None,
        base_url: str = "https://api.ucloud.cn",
        user_agent: str = None,
        timeout: int = 30,
        max_retries: int = 3,
        log_level: int = logging.INFO,
        ssl_verify: bool = True,
        ssl_cacert: str = None,
        ssl_cert: str = None,
        ssl_key: str = None,
        **kwargs
    ):
        self.region = region
        self.project_id = project_id
        self.base_url = base_url
        self.user_agent = user_agent
        self.timeout = timeout
        self.max_retries = max_retries
        self.log_level = log_level
        self.ssl_verify = ssl_verify
        self.ssl_cacert = ssl_cacert
        self.ssl_cert = ssl_cert
        self.ssl_key = ssl_key

    @classmethod
    def from_dict(cls, d: dict):
        parsed = ConfigSchema().dumps(d)
        return cls(**parsed)

    def to_dict(self) -> dict:
        return {
            "region": self.region,
            "project_id": self.project_id,
            "base_url": self.base_url,
            "user_agent": self.user_agent,
            "timeout": self.timeout,
            "max_retries": self.max_retries,
            "log_level": self.log_level,
            "ssl_verify": self.ssl_verify,
            "ssl_cacert": self.ssl_cacert,
            "ssl_cert": self.ssl_cert,
            "ssl_key": self.ssl_key,
        }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core import client


class Client(client.Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        self._config = config
        super(Client, self).__init__(
            self._auto_config(), transport, middleware, logger
        )

    def pathx(self):
        from ucloud.services.pathx.client import PathXClient

        return PathXClient(
            self._auto_config("pathx"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def cube(self):
        from ucloud.services.cube.client import CubeClient

        return CubeClient(
            self._auto_config("cube"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def iam(self):
        from ucloud.services.iam.client import IAMClient

        return IAMClient(
            self._auto_config("iam"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ipsecvpn(self):
        from ucloud.services.ipsecvpn.client import IPSecVPNClient

        return IPSecVPNClient(
            self._auto_config("ipsecvpn"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def isms(self):
        from ucloud.services.isms.client import ISMSClient

        return ISMSClient(
            self._auto_config("isms"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def stepflow(self):
        from ucloud.services.stepflow.client import StepFlowClient

        return StepFlowClient(
            self._auto_config("stepflow"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def tidb(self):
        from ucloud.services.tidb.client import TiDBClient

        return TiDBClient(
            self._auto_config("tidb"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uaccount(self):
        from ucloud.services.uaccount.client import UAccountClient

        return UAccountClient(
            self._auto_config("uaccount"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ubill(self):
        from ucloud.services.ubill.client import UBillClient

        return UBillClient(
            self._auto_config("ubill"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ucdn(self):
        from ucloud.services.ucdn.client import UCDNClient

        return UCDNClient(
            self._auto_config("ucdn"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def udb(self):
        from ucloud.services.udb.client import UDBClient

        return UDBClient(
            self._auto_config("udb"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uddb(self):
        from ucloud.services.uddb.client import UDDBClient

        return UDDBClient(
            self._auto_config("uddb"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def udpn(self):
        from ucloud.services.udpn.client import UDPNClient

        return UDPNClient(
            self._auto_config("udpn"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def udts(self):
        from ucloud.services.udts.client import UDTSClient

        return UDTSClient(
            self._auto_config("udts"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def udisk(self):
        from ucloud.services.udisk.client import UDiskClient

        return UDiskClient(
            self._auto_config("udisk"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uec(self):
        from ucloud.services.uec.client import UECClient

        return UECClient(
            self._auto_config("uec"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ufs(self):
        from ucloud.services.ufs.client import UFSClient

        return UFSClient(
            self._auto_config("ufs"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ufile(self):
        from ucloud.services.ufile.client import UFileClient

        return UFileClient(
            self._auto_config("ufile"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uhost(self):
        from ucloud.services.uhost.client import UHostClient

        return UHostClient(
            self._auto_config("uhost"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uhub(self):
        from ucloud.services.uhub.client import UHubClient

        return UHubClient(
            self._auto_config("uhub"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uk8s(self):
        from ucloud.services.uk8s.client import UK8SClient

        return UK8SClient(
            self._auto_config("uk8s"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def ulb(self):
        from ucloud.services.ulb.client import ULBClient

        return ULBClient(
            self._auto_config("ulb"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def umem(self):
        from ucloud.services.umem.client import UMemClient

        return UMemClient(
            self._auto_config("umem"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def unvs(self):
        from ucloud.services.unvs.client import UNVSClient

        return UNVSClient(
            self._auto_config("unvs"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def unet(self):
        from ucloud.services.unet.client import UNetClient

        return UNetClient(
            self._auto_config("unet"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uphost(self):
        from ucloud.services.uphost.client import UPHostClient

        return UPHostClient(
            self._auto_config("uphost"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uphone(self):
        from ucloud.services.uphone.client import UPhoneClient

        return UPhoneClient(
            self._auto_config("uphone"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def usms(self):
        from ucloud.services.usms.client import USMSClient

        return USMSClient(
            self._auto_config("usms"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def utsdb(self):
        from ucloud.services.utsdb.client import UTSDBClient

        return UTSDBClient(
            self._auto_config("utsdb"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def uvms(self):
        from ucloud.services.uvms.client import UVMSClient

        return UVMSClient(
            self._auto_config("uvms"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def vpc(self):
        from ucloud.services.vpc.client import VPCClient

        return VPCClient(
            self._auto_config("vpc"),
            self.transport,
            self.middleware,
            self.logger,
        )

    def _auto_config(self, package="generic"):
        user_agent = "Package/{} {}".format(
            package, self._config.get("user_agent") or ""
        )
        return dict(user_agent=user_agent.rstrip(), **self._config)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.uddb.schemas import apis


class UDDBClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UDDBClient, self).__init__(config, transport, middleware, logger)

    def change_uddb_instance_name(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ChangeUDDBInstanceName - 修改分布式数据库中间件名称

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **NewName** (str) - (Required) 名称
        - **UDDBId** (str) - (Required) UDDB实例Id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ChangeUDDBInstanceNameRequestSchema().dumps(d)

        resp = self.invoke("ChangeUDDBInstanceName", d, **kwargs)
        return apis.ChangeUDDBInstanceNameResponseSchema().loads(resp)

    def change_uddb_slave_count(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ChangeUDDBSlaveCount - 改变分布式数据库数据节点的只读实例个数每一个UDDB的数据节点负责处理所有的写入请求。与此同时，每一个数据节点可以配置若干个该节点的只读实例。当主节点的数据写入完毕后，只读实例把这次的写入操作进行更新，从而和数据节点保持一致。只读实例可以使得数据由多份复制，在数据节点和只读实例之间，可以做请求的读写分离, 也就是说, 主节点写入数据之后, 数据的读操作可以由数据只读实例进行分担, 这样减少主节点的压力, 增加性能当改变了数据节点的只读实例个数之后，对于现有的和以后的每一个数据节点都采用这个配置。如果UDDB实例有现有的数据节点, 那么它会根据新配置的参数，自动创建或删除数据节点的只读实例如下状态的UDDB实例可以进行这个操作:Running: 系统正常运行中当请求返回成功之后，UDDB实例的状态变成"ChangingSlaveCount"; 如果返回失败, UDDB实例状态保持不变 当UDDB更改数据分区的只读实例个数成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果更改过程中出现异常, 状态变成"Abnormal"(异常运行中)或者"Error"(运行错误)

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **SlaveCount** (str) - (Required) 每个数据节点的只读实例个数, 取值必须>=0
        - **UDDBId** (str) - (Required) UDDB资源id
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ChangeUDDBSlaveCountRequestSchema().dumps(d)

        resp = self.invoke("ChangeUDDBSlaveCount", d, **kwargs)
        return apis.ChangeUDDBSlaveCountResponseSchema().loads(resp)

    def create_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUDDBInstance - 创建创建分布式数据库UDDB实例, 简称UDDB实例。

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **AdminPassword** (str) - (Required) 管理员密码, 密码需要使用base64加密
        - **DBTypeId** (str) - (Required) UDDB的数据库版本，支持版本如下：mysql-5.6 mysql-5.7. 如果不填，则默认为mysql-5.6
        - **DataNodeCount** (int) - (Required) 初始的数据节点个数 取值必须>0.
        - **DataNodeDiskSpace** (int) - (Required) 新的数据节点的磁盘大小配置. 单位: GB 具体数值参考UDB的磁盘大小取值.
        - **DataNodeMemory** (int) - (Required) 新的数据节点的内存配置, 单位：MB 具体数值参考UDB的内存取值.
        - **Name** (str) - (Required) 实例名称，至少6位
        - **RouterNodeNum** (int) - (Required) 其他版本：该参数可不填；专享版：物理机台数
        - **RouterVersion** (str) - (Required) UDDB路由节点的版本。分为三种： Trival(免费版)： 2中间件节点； QPS：1.5W FellFree(标准版)： 固定为4中间件节点，后续将根据业务请求量自动扩展，最多扩展到12个节点，QPS为3w - 10w； EnjoyAlone(物理机版)：专享物理机，节点数让客户可选
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **AdminUser** (str) - 管理员帐户名，默认root
        - **ChargeType** (str) - 付费类型，可选值如下:Year: 按年付费 Month: 按月付费 Dynamic: 按需付费(单位: 小时) Trial: 免费试用  默认值为: Dynamic
        - **CouponId** (str) - 使用的代金券id
        - **DataNodeSlaveCount** (int) - 每个数据节点的只读实例个数, 取值必须>=0. 默认取值为0.
        - **InstanceMode** (str) - 存储节点的高可用模式， 分为高可用UDB（HA）和普通UDB（Normal），如果不填， 则默认为HA
        - **InstanceType** (str) - 存储节点和只读实例的磁盘类型。分为：SSD磁盘（SATA_SSD）或普通磁盘(Normal)。 如果不填，则默认为SATA_SSD
        - **Port** (int) - 端口号，mysql默认端口为3306
        - **Quantity** (int) - 购买时长，默认值1
        - **SubnetId** (str) - 子网ID
        - **VPCId** (str) - VPC的ID

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息
        - **UDDBId** (str) - UDDB实例ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUDDBInstanceRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUDDBInstance", d, **kwargs)
        return apis.CreateUDDBInstanceResponseSchema().loads(resp)

    def delete_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUDDBInstance - 删除UDDB实例。如下状态的UDDB实例可以进行这个操作:InitFail: 初始化失败Shutoff: 已关闭当请求返回成功之后，UDDB实例就已经被删除, 列表上看不到对应的UDDB实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("DeleteUDDBInstance", d, **kwargs)
        return apis.DeleteUDDBInstanceResponseSchema().loads(resp)

    def describe_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUDDBInstance - 获取分布式数据库UDDB的详细信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **DataSet** (list) - 见 **DataSetUDDB** 模型定义
        - **Message** (str) - 如果执行失败, 失败的错误消息

        **Response Model**

        **DataSetUDDB**
        - **AdminUser** (str) - 管理员帐户名，默认root
        - **ChargeType** (str) - 付费类型，可选值如下: Year: 按年付费 Month: 按月付费 Dynamic: 按需付费(单位: 小时) Trial: 免费试用
        - **CreateTime** (str) - UDDB实例创建时间，采用UTC计时时间戳
        - **DBTypeId** (str) - UDDB的数据库版本
        - **DataNodeCount** (str) - 数据节点个数
        - **DataNodeDiskSpace** (str) - 数据节点的磁盘大小配置. 单位: GB
        - **DataNodeList** (list) - 见 **DataNodeInfo** 模型定义
        - **DataNodeMemory** (str) - 数据节点的内存配置, 单位：MB
        - **DataNodeSlaveCount** (str) - 每个数据节点的只读实例个数.
        - **ExpiredTime** (str) - UDDB实例过期时间，采用UTC计时时间戳
        - **InstanceMode** (str) - 存储节点的高可用模式， 分为高可用UDB（HA）和普通UDB（Normal），如果不填， 则默认为HA
        - **InstanceType** (str) - 存储节点和只读实例的磁盘类型。分为：SSD磁盘（SATA_SSD）或普通磁盘(Normal)。 如果不填，则默认为SATA_SSD
        - **Name** (str) - UDDB实例名称
        - **Port** (str) - UDDB实例访问的端口号
        - **RefQps** (int) - 参考QPS。 免费版： 15000； 畅享版： 30000 - 100000 （根据节点数而定）； 专享版： 节点数 * 10w qps
        - **RouterNodeNum** (int) - 各版本下的节点个数。体验版： 固定为2节点； 畅享版：固定为4节点（后续可通过管理API调整）；专享版：物理机台数
        - **RouterVersion** (str) - UDDB路由节点的版本。分为三种： Trival(免费版)： 2中间件节点； QPS：1.5W FellFree(标准版)： 固定为4中间件节点，后续将根据业务请求量自动扩展，最多扩展到12个节点，QPS为3w - 10w； EnjoyAlone(物理机版)：专享物理机，节点数让客户可选
        - **State** (str) - UDDB状态, 状态列表如下: Init: 初始化中 InitFail: 初始化失败 Starting: 启动中 Running: 系统正常运行中 Abnormal: 系统运行中, 有异常, 还能提供服务 Error: 系统运行中, 但不能正常提供服务 Shutdown: 关闭中 Shutoff: 已关闭 Deleted: 已删除 UpgradingUDDB: 升降级UDDB配置中 UpgradingDataNode: 升降级UDDB节点配置中 ChangingSlaveCount: 改变只读实例数量中 ScalingOutUDDB: 水平扩展中
        - **UDDBId** (str) - UDDB实例ID
        - **VirtualIP** (str) - UDDB实例访问的虚IP
        - **Zone** (str) - UDDB实例对应的可用区


        **DataNodeInfo**
        - **CreateTime** (str) - 节点的创建时间
        - **DiskSpace** (str) - 数据节点的磁盘大小配置. 单位: GB
        - **Id** (str) - 数据节点ID
        - **LastTransTaskId** (str) - 最近一次数据迁移任务id
        - **Memory** (str) - 数据节点的内存配置, 单位：MB
        - **SlaveCount** (str) - 数据节点的只读实例个数.
        - **SlaveInfos** (list) - 见 **SlaveInfo** 模型定义
        - **State** (str) - 数据分片状态, 状态列表如下: Init: 初始化中 Fail: 安装失败 Starting: 启动中 Running: 系统正常运行中 Shutdown: 关闭中 Shutoff: 已关闭 Deleted: 已删除 Upgrading: 系统升级中


        **SlaveInfo**
        - **DataNodeId** (str) - 对应数据节点的ID
        - **Id** (str) - 只读实例ID
        - **State** (str) - 只读实例状态, 状态列表如下: Init: 初始化中 Fail: 安装失败 Starting: 启动中 Running: 系统正常运行中 Shutdown: 关闭中 Shutoff: 已关闭 Deleted: 已删除 Upgrading: 系统升级中


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUDDBInstance", d, **kwargs)
        return apis.DescribeUDDBInstanceResponseSchema().loads(resp)

    def describe_uddb_instance_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUDDBInstancePrice - 获取分布式数据库UDDB价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DataNodeCount** (int) - (Required) 初始的数据节点个数 取值必须>0.
        - **DataNodeDiskSpace** (int) - (Required) 新的数据节点的磁盘大小配置. 单位: GB 具体数值参考UDB的磁盘大小取值.
        - **DataNodeMemory** (str) - (Required) 新的数据节点的内存配置, 单位：MB 具体数值参考UDB的内存取值.
        - **RouterNodeNum** (int) - (Required) 其他版本：该参数可不填；专享版：物理机节点个数。一台物理机有2个节点
        - **RouterVersion** (str) - (Required) UDDB路由节点的版本。分为三种： Trival(免费版)： 2中间件节点； QPS：1.5WFeelFree(标准版)： 固定为4中间件节点，后续将根据业务请求量自动扩展，最多扩展到12个节点，QPS为3w - 10w；EnjoyAlone(物理机版)：专享物理机，节点数让客户可选
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **ChargeType** (str) - 付费类型，可选值如下: Year: 按年付费 Month: 按月付费 Dynamic: 按需付费(单位: 小时) Trial: 免费试用 默认值为: Dynamic
        - **DataNodeSlaveCount** (int) - 每个数据节点的只读实例个数, 取值必须>=0. 默认取值为0.
        - **InstanceMode** (str) - 存储节点的高可用模式， 分为高可用UDB（HA）和普通UDB（Normal），如果不填， 则默认为HA
        - **InstanceType** (str) - 存储节点和只读实例的磁盘类型。分为：SSD磁盘（SATA_SSD）或普通磁盘(Normal)。 如果不填，则默认为SATA_SSD
        - **Quantity** (int) - 购买时长，默认值1

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息
        - **PriceInfo** (dict) - 见 **PriceDetailInfo** 模型定义

        **Response Model**

        **PriceDetailInfo**
        - **DataNodePrice** (float) - 存储节点费用
        - **DataNodeSlavePrice** (float) - 只读实例费用
        - **MiddlewarePrice** (float) - 中间件路由节点费用


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUDDBInstancePriceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUDDBInstancePrice", d, **kwargs)
        return apis.DescribeUDDBInstancePriceResponseSchema().loads(resp)

    def describe_uddb_instance_upgrade_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUDDBInstanceUpgradePrice - 升级UDDB时，获取升级后的价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **RouterNodeNum** (int) - (Required) 其他版本：该参数可不填；专享版：物理机节点的个数。一台物理机有2个节点
        - **RouterVersion** (str) - (Required) UDDB路由节点的版本。分为三种： Trival(免费版)： 2中间件节点； QPS：1.5WFeelFree(标准版)： 固定为4中间件节点，后续将根据业务请求量自动扩展，最多扩展到12个节点，QPS为3w - 10w；EnjoyAlone(物理机版)：专享物理机，节点数让客户可选
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DataNodeCount** (int) - 新的数据节点个数 取值必须>0.
        - **DataNodeDiskSpace** (int) - 新的数据节点的磁盘大小配置. 单位: GB 具体数值参考UDB的磁盘大小取值.
        - **DataNodeMemory** (int) - 新的数据节点的内存配置, 单位：MB 具体数值参考UDB的内存取值.
        - **DataNodeSlaveCount** (int) - 每个数据节点的只读实例个数, 取值必须>=0.
        - **InstanceMode** (str) - 存储节点的高可用模式， 分为高可用UDB（HA）和普通UDB（Normal），如果不填， 则默认为HA
        - **InstanceType** (str) - 存储节点和只读实例的磁盘类型。分为：SSD磁盘（SATA_SSD）或普通磁盘(Normal)。 如果不填，则默认为SATA_SSD

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息
        - **PriceInfo** (dict) - 见 **PriceInfo** 模型定义

        **Response Model**

        **PriceInfo**
        - **DataNodePrice** (float) - 存储节点费用
        - **DataNodeSlavePrice** (float) - 只读实例费用
        - **MiddlewarePrice** (float) - 中间件路由节点费用


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUDDBInstanceUpgradePriceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUDDBInstanceUpgradePrice", d, **kwargs)
        return apis.DescribeUDDBInstanceUpgradePriceResponseSchema().loads(resp)

    def restart_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """RestartUDDBInstance - 重启UDDB实例，开始提供服务。如下状态的UDDB实例可以进行这个操作:Running: 正常运行中Abnormal: 异常运行中当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在重启过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.RestartUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("RestartUDDBInstance", d, **kwargs)
        return apis.RestartUDDBInstanceResponseSchema().loads(resp)

    def start_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StartUDDBInstance - 启动UDDB实例，开始提供服务。如下状态的UDDB实例可以进行这个操作:Shutoff: 已关闭当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在启动过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭)

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StartUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("StartUDDBInstance", d, **kwargs)
        return apis.StartUDDBInstanceResponseSchema().loads(resp)

    def stop_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StopUDDBInstance - 关闭UDDB实例，停止提供服务。如下状态的UDDB实例可以进行这个操作:Running: 正常运行中Abnormal: 异常运行中当请求返回成功之后，UDDB实例的状态变成"Shutdown"(关闭中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在关闭过程中, 当UDDB实例关闭成功之后, UDDB实例的状态变成"Shutoff"(已关闭); 如果关闭过程中出现异常, 根据UDDB实例的情况, 状态变成"Abnormal"(异常运行中), 或者"Running"(正常运行中)

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StopUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("StopUDDBInstance", d, **kwargs)
        return apis.StopUDDBInstanceResponseSchema().loads(resp)

    def upgrade_uddb_data_node(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpgradeUDDBDataNode - 升降级分布式数据库数据节点的配置, 提高/降低数据节点的数据容量和内存所有数据节点以及其所挂载的只读实例的配置都受到影响升降级数据节点的配置之后之后, 会按照数据节点新的磁盘和内存大小重新计费如下状态的数据节点实例可以进行这个操作:Shutoff: 已关闭当请求返回成功之后，UDDB实例的状态变成"UpgradingDataNode"，相关数据节点的状态变成"Upgrading"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级结束之后, UDDB实例的状态变成"Shutoff"

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DataNodeDiskSpace** (int) - (Required) 新的数据节点的磁盘大小配置. 单位: GB 具体数值参考UDB的磁盘大小取值.
        - **DataNodeMemory** (int) - (Required) 新的数据节点的内存配置, 单位：MB 具体数值参考UDB的内存取值
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **CouponId** (str) - 使用的代金券id
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpgradeUDDBDataNodeRequestSchema().dumps(d)

        resp = self.invoke("UpgradeUDDBDataNode", d, **kwargs)
        return apis.UpgradeUDDBDataNodeResponseSchema().loads(resp)

    def upgrade_uddb_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpgradeUDDBInstance - 升降级分布式数据库中间件的配置, 提高/降低请求处理的并发性修改请求处理节点个数之后, 按照所有请求处理节点的总内存容量和CPU核数重新计费如下状态的UDDB实例可以进行这个操作:Running: 系统正常运行中当请求返回成功之后，UDDB实例的状态变成"UpgradingUDDB"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级成功之后, UDDB实例的状态变成"Running"; 如果更改过程中出现异常, 状态变成"Abnormal", 或者"Error"

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **RouterNodeNum** (int) - (Required) 其他版本：该参数可不填；专享版：物理机台数
        - **RouterVersion** (str) - (Required) UDDB路由节点的版本。分为三种： Trival(免费版)： 2中间件节点； QPS：1.5W FellFree(标准版)： 固定为4中间件节点，后续将根据业务请求量自动扩展，最多扩展到12个节点，QPS为3w - 10w； EnjoyAlone(物理机版)：专享物理机，节点数让客户可选
        - **UDDBId** (str) - (Required) UDDB实例ID
        - **CouponId** (str) - 使用的代金券id
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Message** (str) - 如果执行失败, 失败的错误消息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpgradeUDDBInstanceRequestSchema().dumps(d)

        resp = self.invoke("UpgradeUDDBInstance", d, **kwargs)
        return apis.UpgradeUDDBInstanceResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.uphost.schemas import apis


class UPHostClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UPHostClient, self).__init__(
            config, transport, middleware, logger
        )

    def create_phost(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """CreatePHost - 指定数据中心，根据资源使用量创建指定数量的UPHost物理云主机实例。

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageId** (str) - (Required) ImageId，可以通过接口  `DescribePHostImage <https://docs.ucloud.cn/api/uphost-api/api/uphost-api/describe_phost_image.html>`_ 获取
        - **Password** (str) - (Required) 密码（密码需使用base64进行编码）
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - 计费模式，枚举值为：year, 按年付费； month,按月付费；默认为按月付费
        - **Cluster** (str) - 网络环境，可选千兆：1G ，万兆：10G， 默认1G。智能网卡可以选择25G。
        - **CouponId** (str) - 代金券
        - **Disks** (list) - 见 **CreatePHostParamDisks** 模型定义
        - **Name** (str) - 物理机名称，默认为phost
        - **Quantity** (str) - 购买时长，1-10个月或1-10年；默认值为1。月付时，此参数传0，代表购买至月末，1代表整月。
        - **Raid** (str) - Raid配置，默认Raid10  支持:Raid0、Raid1、Raid5、Raid10，NoRaid
        - **Remark** (str) - 物理机备注，默认为空
        - **SecurityGroupId** (str) - 防火墙ID，默认：Web推荐防火墙。如何查询SecurityGroupId请参见  `DescribeFirewall <https://docs.ucloud.cn/api/uphost-api/api/unet-api/describe_firewall.html>`_ 。
        - **SubnetId** (str) - 子网ID，不填为默认，VPC2.0下需要填写此字段。
        - **Tag** (str) - 业务组，默认为default
        - **Type** (str) - 物理机类型，默认为：db-2(基础型-SAS-V3)
        - **VPCId** (str) - VPC ID，不填为默认，VPC2.0下需要填写此字段。
        - **VpcIp** (str) - 指定内网ip创建

        **Response**

        - **PHostId** (list) - PHost的资源ID数组

        **Request Model**

        **CreatePHostParamDisks**
        - **CouponId** (str) - 裸金属机型参数->云盘代金券id。不适用于系统盘。请通过DescribeCoupon接口查询，或登录用户中心查看
        - **IsBoot** (str) - 裸金属机型参数->是否是系统盘。枚举值： True，是系统盘。 False，是数据盘（默认）。Disks数组中有且只能有一块盘是系统盘。
        - **Size** (int) - 裸金属机型参数->磁盘大小，单位GB，必须是10GB的整数倍。系统盘20-500GB，数据盘单块盘20-32000GB。
        - **Type** (str) - 裸金属机型参数->磁盘类型：枚举值：CLOUD_RSSD


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreatePHostRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreatePHost", d, **kwargs)
        return apis.CreatePHostResponseSchema().loads(resp)

    def create_phost_image(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreatePHostImage - 创建裸金属2.0用户自定义镜像

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageName** (str) - (Required) 镜像名称
        - **PHostId** (str) - (Required) UPHost实例ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageDescription** (str) - 镜像描述

        **Response**

        - **ImageId** (str) - 镜像ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreatePHostImageRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreatePHostImage", d, **kwargs)
        return apis.CreatePHostImageResponseSchema().loads(resp)

    def describe_baremetal_machine_type(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeBaremetalMachineType - 获取裸金属机型的详细描述信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Type** (str) - 具体机型。若不填写，则返回全部机型

        **Response**

        - **MachineTypes** (list) - 见 **PHostCloudMachineTypeSet** 模型定义

        **Response Model**

        **PHostCloudMachineTypeSet**
        - **CPU** (dict) - 见 **PHostCPUSet** 模型定义
        - **Clusters** (list) - 见 **PHostClusterSet** 模型定义
        - **Components** (dict) - 见 **PHostComponentSet** 模型定义
        - **Memory** (int) - 内存大小，单位MB
        - **Type** (str) - 物理云主机机型别名，全网唯一。


        **PHostCPUSet**
        - **CoreCount** (int) - CPU核数
        - **Count** (int) - CPU个数
        - **Frequence** (float) - CPU主频
        - **Model** (str) - CPU型号


        **PHostClusterSet**
        - **Name** (str) - 集群名。枚举值：千兆网络集群：1G；万兆网络集群：10G；智能网卡网络：25G；
        - **StockStatus** (str) - 库存状态。枚举值：有库存：Available；无库存：SoldOut


        **PHostComponentSet**
        - **Count** (int) - 组件数量
        - **Name** (str) - 组件名称


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeBaremetalMachineTypeRequestSchema().dumps(d)

        resp = self.invoke("DescribeBaremetalMachineType", d, **kwargs)
        return apis.DescribeBaremetalMachineTypeResponseSchema().loads(resp)

    def describe_phost(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePHost - 获取物理机详细信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Limit** (int) - 返回数据长度，默认为20
        - **Offset** (int) - 数据偏移量，默认为0
        - **PHostId** (list) - PHost资源ID，若为空，则返回当前Region所有PHost。
        - **UDiskIdForAttachment** (str) - 要挂载的云盘id，过滤返回能被UDiskId挂载的云主机。目前主要针对rssd云盘使用
        - **VPCId** (str) - ULB使用参数，获取同VPC下机器信息。
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **PHostSet** (list) - 见 **PHostSet** 模型定义
        - **TotalCount** (int) - 满足条件的PHost总数

        **Response Model**

        **PHostSet**
        - **AutoRenew** (str) - 自动续费
        - **CPUSet** (dict) - 见 **PHostCPUSet** 模型定义
        - **ChargeType** (str) - 计费模式，枚举值为： Year，按年付费； Month，按月付费；默认为月付
        - **Cluster** (str) - 网络环境。枚举值：千兆：1G ，万兆：10G
        - **Components** (str) - 组件信息（暂不支持）
        - **CreateTime** (int) - 创建时间
        - **DiskSet** (list) - 见 **PHostDescDiskSet** 模型定义
        - **ExpireTime** (int) - 到期时间
        - **IPSet** (list) - 见 **PHostIPSet** 模型定义
        - **ImageName** (str) - 镜像名称
        - **IsSupportKVM** (str) - 是否支持紧急登录
        - **Memory** (int) - 内存大小，单位：MB
        - **Name** (str) - 物理机名称
        - **OSType** (str) - 操作系统类型
        - **OSname** (str) - 操作系统名称
        - **PHostId** (str) - PHost资源ID
        - **PHostType** (str) - 物理机类型，参见DescribePHostMachineType返回值
        - **PMStatus** (str) - 物理云主机状态。枚举值：\\ > 初始化:Initializing; \\ > 启动中：Starting； \\ > 运行中：Running；\\ > 关机中：Stopping； \\ > 安装失败：InstallFailed； \\ > 重启中：Rebooting；\\ > 关机：Stopped； \\ > 迁移中(裸金属云盘)：Migrating
        - **PhostClass** (str) - 物理云产品类型，枚举值：LocalDisk=>代表传统本地盘机型， CloudDisk=>云盘裸金属机型
        - **PowerState** (str) - 电源状态，on 或 off
        - **RaidSupported** (str) - 是否支持Raid。枚举值：Yes：支持；No：不支持。
        - **Remark** (str) - 物理机备注
        - **SN** (str) - 物理机序列号
        - **Tag** (str) - 业务组
        - **Zone** (str) - 可用区，参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_


        **PHostCPUSet**
        - **CoreCount** (int) - CPU核数
        - **Count** (int) - CPU个数
        - **Frequence** (float) - CPU主频
        - **Model** (str) - CPU型号


        **PHostDescDiskSet**
        - **Count** (int) - 磁盘数量
        - **DiskId** (str) - 裸金属机型参数：磁盘ID
        - **Drive** (str) - 裸金属机型参数：磁盘盘符
        - **IOCap** (int) - 磁盘IO性能，单位MB/s（待废弃）
        - **IsBoot** (str) - 裸金属机型参数：是否是启动盘。True/False
        - **Name** (str) - 磁盘名称，sys/data
        - **Space** (int) - 单盘大小，单位GB
        - **Type** (str) - 磁盘属性


        **PHostIPSet**
        - **Bandwidth** (int) - IP对应带宽，单位Mb，内网IP不显示带宽信息
        - **IPAddr** (str) - IP地址，
        - **IPId** (str) - IP资源ID(内网IP无资源ID)（待废弃）
        - **MACAddr** (str) - MAC地址
        - **OperatorName** (str) - 国际: Internation， BGP: BGP， 内网: Private
        - **SubnetId** (str) - 子网ID
        - **VPCId** (str) - VPC ID


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribePHostRequestSchema().dumps(d)

        resp = self.invoke("DescribePHost", d, **kwargs)
        return apis.DescribePHostResponseSchema().loads(resp)

    def describe_phost_image(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePHostImage - 获取物理云主机镜像列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageId** (list) - 镜像ID
        - **ImageType** (str) - 镜像类别，枚举值，Base是基础镜像；Custom是自制镜像。
        - **Limit** (int) - 返回数据长度，默认为20
        - **MachineType** (str) - 机器型号，只支持当前zone的展示机型
        - **Offset** (int) - 数据偏移量，默认为0

        **Response**

        - **ImageSet** (list) - 见 **PHostImageSet** 模型定义
        - **TotalCount** (int) - 满足条件的镜像总数

        **Response Model**

        **PHostImageSet**
        - **CreateTime** (int) - 裸金属2.0参数。镜像创建时间。
        - **ImageDescription** (str) - 镜像描述
        - **ImageId** (str) - 镜像ID
        - **ImageName** (str) - 镜像名称
        - **ImageSize** (int) - 裸金属2.0参数。镜像大小。
        - **ImageType** (str) - 枚举值：Base=>基础镜像，Custom=>自制镜像。
        - **OsName** (str) - 操作系统名称
        - **OsType** (str) - 操作系统类型
        - **State** (str) - 裸金属2.0参数。镜像当前状态。
        - **Support** (list) - 支持的机型
        - **Version** (str) - 当前版本


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribePHostImageRequestSchema().dumps(d)

        resp = self.invoke("DescribePHostImage", d, **kwargs)
        return apis.DescribePHostImageResponseSchema().loads(resp)

    def describe_phost_machine_type(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePHostMachineType - 获取物理云机型的详细描述信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Type** (str) - 具体机型。若不填写，则返回全部机型

        **Response**

        - **MachineTypes** (list) - 见 **PHostMachineTypeSet** 模型定义

        **Response Model**

        **PHostMachineTypeSet**
        - **CPU** (dict) - 见 **PHostCPUSet** 模型定义
        - **Clusters** (list) - 见 **PHostClusterSet** 模型定义
        - **Components** (dict) - 见 **PHostComponentSet** 模型定义
        - **Disks** (list) - 见 **PHostDiskSet** 模型定义
        - **Memory** (int) - 内存大小，单位MB
        - **RaidSupported** (str) - 是否支持Raid。枚举值：支持：YES；不支持：NO
        - **Type** (str) - 物理云主机机型别名，全网唯一。


        **PHostCPUSet**
        - **CoreCount** (int) - CPU核数
        - **Count** (int) - CPU个数
        - **Frequence** (float) - CPU主频
        - **Model** (str) - CPU型号


        **PHostClusterSet**
        - **Name** (str) - 集群名。枚举值：千兆网络集群：1G；万兆网络集群：10G；智能网卡网络：25G；
        - **StockStatus** (str) - 库存状态。枚举值：有库存：Available；无库存：SoldOut


        **PHostComponentSet**
        - **Count** (int) - 组件数量
        - **Name** (str) - 组件名称


        **PHostDiskSet**
        - **Count** (int) - 磁盘数量
        - **IOCap** (int) - 磁盘IO性能，单位MB/s（待废弃）
        - **Name** (str) - 磁盘名称，sys/data
        - **Space** (int) - 单盘大小，单位GB
        - **Type** (str) - 磁盘属性


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribePHostMachineTypeRequestSchema().dumps(d)

        resp = self.invoke("DescribePHostMachineType", d, **kwargs)
        return apis.DescribePHostMachineTypeResponseSchema().loads(resp)

    def describe_phost_tags(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribePHostTags - 获取物理机tag列表（业务组）

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **TagSet** (list) - 见 **PHostTagSet** 模型定义
        - **TotalCount** (int) - Tag的个数

        **Response Model**

        **PHostTagSet**
        - **Tag** (str) - 业务组名称
        - **TotalCount** (int) - 该业务组中包含的主机个数


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribePHostTagsRequestSchema().dumps(d)

        resp = self.invoke("DescribePHostTags", d, **kwargs)
        return apis.DescribePHostTagsResponseSchema().loads(resp)

    def get_phost_disk_upgrade_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetPHostDiskUpgradePrice - 获取物理云裸金属挂载磁盘的升级价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DiskSpace** (int) - (Required) 磁盘大小，单位GB，必须是10GB的整数倍。系统盘20-500GB，数据盘单块盘20-32000GB。
        - **PHostId** (str) - (Required) UPHost实例ID。
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **ReinstallTag** (bool) - 是否重装价格获取。复用此接口。扩容只能增加云盘大小。重装不限制。枚举值：true/false
        - **UDiskId** (str) - 磁盘 ID。获取扩容价格必填（只能扩不能减）；重装时候不需要填（根据所选盘大小决定）

        **Response**

        - **OriginalPrice** (float) - 升价差价原价。精度为小数点后2位。
        - **Price** (float) - 升级差价。精度为小数点后2位。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetPHostDiskUpgradePriceRequestSchema().dumps(d)

        resp = self.invoke("GetPHostDiskUpgradePrice", d, **kwargs)
        return apis.GetPHostDiskUpgradePriceResponseSchema().loads(resp)

    def get_phost_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetPHostPrice - 获取物理机价格列表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ChargeType** (str) - (Required) 计费模式，枚举值为： Year/Month
        - **Count** (int) - (Required) 购买数量，范围[1-5]
        - **Quantity** (int) - (Required) 购买时长，1-10个月或1-10年；默认值为1。月付时，此参数传0，代表购买至月末，1代表整月。
        - **Cluster** (str) - 网络环境，可选千兆：1G ；万兆：10G；25G网络：25G。
        - **Disks** (list) - 见 **GetPHostPriceParamDisks** 模型定义
        - **Type** (str) - 默认为：DB(数据库型)，可以通过接口  `DescribePHostMachineType <https://docs.ucloud.cn/api/uphost-api/api/uphost-api/describe_phost_machine_type.html>`_ 获取
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **PriceSet** (list) - 见 **PHostPriceSet** 模型定义

        **Request Model**

        **GetPHostPriceParamDisks**
        - **IsBoot** (str) - 裸金属机型参数->枚举值：\\ > True，是系统盘 \\ > False，是数据盘（默认）。Disks数组中有且只能有一块盘是系统盘。
        - **Size** (str) - 裸金属机型参数->磁盘大小，单位GB，必须是10GB的整数倍。系统盘20-500GB。数据盘是20-32000G。
        - **Type** (str) - 裸金属机型参数->磁盘类型：枚举值：CLOUD_RSSD


        **Response Model**

        **PHostPriceSet**
        - **ChargeType** (str) - Year/Month
        - **OriginalPrice** (float) - 原价格, 单位:元, 保留小数点后两位有效数字
        - **Price** (float) - 价格, 单位:元, 保留小数点后两位有效数字
        - **Product** (str) - 枚举值：phost=>为主机价格，如果是云盘包括了系统盘价格。cloudDisk=>所有数据盘价格，只是裸金属机型才返回此参数。


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetPHostPriceRequestSchema().dumps(d)

        resp = self.invoke("GetPHostPrice", d, **kwargs)
        return apis.GetPHostPriceResponseSchema().loads(resp)

    def get_phost_disk_upgrade_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetPhostDiskUpgradePrice - 获取物理云裸金属挂载磁盘的升级价格

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DiskId** (str) - (Required) 磁盘ID。
        - **DiskSpace** (int) - (Required) 裸金属机型参数->磁盘大小，单位GB，必须是10GB的整数倍。系统盘20-500GB，数据盘单块盘20-32000GB。
        - **PHostId** (str) - (Required) UPHost实例ID。
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **Price** (float) - 升级差价。精度为小数点后2位。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetPhostDiskUpgradePriceRequestSchema().dumps(d)

        resp = self.invoke("GetPhostDiskUpgradePrice", d, **kwargs)
        return apis.GetPhostDiskUpgradePriceResponseSchema().loads(resp)

    def modify_phost_image_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyPHostImageInfo - 修改自定义镜像名称和备注

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageId** (str) - (Required) 镜像ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Name** (str) - 镜像名称
        - **Remark** (str) - 备注

        **Response**

        - **ImageId** (str) - 镜像ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyPHostImageInfoRequestSchema().dumps(d)

        resp = self.invoke("ModifyPHostImageInfo", d, **kwargs)
        return apis.ModifyPHostImageInfoResponseSchema().loads(resp)

    def modify_phost_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyPHostInfo - 更改物理机信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) 物理机资源ID
        - **Name** (str) - 物理机名称，默认不更改
        - **Remark** (str) - 物理机备注，默认不更改
        - **Tag** (str) - 业务组，默认不更改
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ModifyPHostInfoRequestSchema().dumps(d)

        resp = self.invoke("ModifyPHostInfo", d, **kwargs)
        return apis.ModifyPHostInfoResponseSchema().loads(resp)

    def poweroff_phost(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """PoweroffPHost - 断电物理云主机

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.PoweroffPHostRequestSchema().dumps(d)

        resp = self.invoke("PoweroffPHost", d, **kwargs)
        return apis.PoweroffPHostResponseSchema().loads(resp)

    def reboot_phost(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """RebootPHost - 重启物理机

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.RebootPHostRequestSchema().dumps(d)

        resp = self.invoke("RebootPHost", d, **kwargs)
        return apis.RebootPHostResponseSchema().loads(resp)

    def reinstall_phost(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ReinstallPHost - 重装物理机操作系统

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **Password** (str) - (Required) 密码
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **BootDiskSpace** (int) - 裸金属机型参数->系统盘大小。 单位：GB， 范围[20,500]， 步长：10
        - **ImageId** (str) - 镜像Id，参考镜像列表，默认使用原镜像
        - **Name** (str) - 物理机名称，默认不更改
        - **Raid** (str) - 不保留数据盘重装，可选Raid
        - **Remark** (str) - 物理机备注，默认为不更改。
        - **ReserveDisk** (str) - 是否保留数据盘，保留：Yes，不报留：No， 默认：Yes
        - **Tag** (str) - 业务组，默认不更改。

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ReinstallPHostRequestSchema().dumps(d)

        resp = self.invoke("ReinstallPHost", d, **kwargs)
        return apis.ReinstallPHostResponseSchema().loads(resp)

    def reset_phost_password(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ResetPHostPassword - 重置裸金属实例的管理员密码

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) 裸金属实例ID
        - **Password** (str) - (Required) PHost新密码（密码格式使用BASE64编码）
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - 裸金属实例ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ResetPHostPasswordRequestSchema().dumps(d)

        resp = self.invoke("ResetPHostPassword", d, **kwargs)
        return apis.ResetPHostPasswordResponseSchema().loads(resp)

    def resize_phost_attached_disk(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ResizePHostAttachedDisk - 修改裸金属物理云已经挂载的云盘容量大小

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **DiskSpace** (int) - 裸金属机型参数->磁盘大小，单位GB，必须是10GB的整数倍。系统盘20-500GB，数据盘单块盘20-32000GB。
        - **PHostId** (str) - UPHost实例ID。
        - **UDiskId** (str) - 磁盘ID。

        **Response**

        - **UDiskId** (str) - 改配成功的磁盘id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.ResizePHostAttachedDiskRequestSchema().dumps(d)

        resp = self.invoke("ResizePHostAttachedDisk", d, **kwargs)
        return apis.ResizePHostAttachedDiskResponseSchema().loads(resp)

    def start_phost(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """StartPHost - 启动物理机

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StartPHostRequestSchema().dumps(d)

        resp = self.invoke("StartPHost", d, **kwargs)
        return apis.StartPHostResponseSchema().loads(resp)

    def stop_phost(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """StopPHost - 关闭物理机

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.StopPHostRequestSchema().dumps(d)

        resp = self.invoke("StopPHost", d, **kwargs)
        return apis.StopPHostResponseSchema().loads(resp)

    def terminate_phost(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """TerminatePHost - 删除物理云主机

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **PHostId** (str) - (Required) PHost资源ID
        - **ReleaseEIP** (bool) - 是否释放绑定的EIP。true: 解绑EIP后，并释放；其他值或不填：解绑EIP。
        - **ReleaseUDisk** (bool) - 裸金属机型参数->删除主机时是否同时删除挂载的数据盘。默认为false。
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_

        **Response**

        - **PHostId** (str) - PHost 的资源ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.TerminatePHostRequestSchema().dumps(d)

        resp = self.invoke("TerminatePHost", d, **kwargs)
        return apis.TerminatePHostResponseSchema().loads(resp)

    def terminate_phost_image(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """TerminatePHostImage - 删除裸金属2.0用户自定义镜像

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **ImageId** (str) - (Required) 自制镜像ID
        - **Zone** (str) - (Required) 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **ImageId** (str) - 自制镜像ID

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.TerminatePHostImageRequestSchema().dumps(d)

        resp = self.invoke("TerminatePHostImage", d, **kwargs)
        return apis.TerminatePHostImageResponseSchema().loads(resp)
